#!/bin/sh
# bin-tc.sh : test case for /usr/bin directory

tet_startup="startup"			# startup function
tet_cleanup="cleanup"			# cleanup function
iclist="ic1 ic2 ic3 ic4"
ic1="tp1"
ic2="tp2"
ic3="tp3"
ic4="tp4"


tp1()
{
	tpstart "Reference 4.3-1(A)"
	tet_infoline "The /usr/bin directory exists and is searchable"
	lsb_test_dir_searchable /usr/bin >out.stdout  2>out.stderr
	check_exit_value $? 0		# should be zero
	check_nostdout			# should be no stdout
	check_nostderr			# should be no stderr
	tpresult				# set result code
}

tp2()
{
	tpstart "Reference 4.3-2(A)"
	tet_infoline "The implementation provides a perl interpreter that can be referenced as /usr/bin/perl"
	(/usr/bin/perl -e 'exit 0') >out.stdout 2>out.stderr
	check_exit_value $? 0		# should be zero
	check_nostdout			# should be no stdout
	check_nostderr			# should be no stderr
	tpresult 			# set result code
}

tp3()
{
	tpstart "Reference 4.3-3(A)"
	tet_infoline "The implementation provides a python interpreter that can be referenced as /usr/bin/python"
	(/usr/bin/python --help ) >out.stdout 2>out.stderr
	lsb_res=$?
	case $lsb_res in
	2) FAIL=N ;;
	*) tet_infoline "Return=$lsb_res"
	   if test -s out.stderr
	   then
		infofile out.stderr "stderr:"
	   fi
	   FAIL=Y ;;
	esac
	check_nostdout			# should be no stdout
	check_stderr			# should be stderr
	tpresult 			# set result code
}
tp4()
{
	tpstart "Reference 4.3-4(A)"
	tet_infoline "The implementation provides a tcl interpreter that can be referenced as /usr/bin/tcl"
	(/usr/bin/tcl --help ) >out.stdout 2>out.stderr
	lsb_res=$?
	case $lsb_res in
	1) FAIL=N ;;
	*) tet_infoline "Return=$lsb_res"
	   if test -s out.stderr
	   then
		infofile out.stderr "stderr:"
	   fi
	   FAIL=Y ;;
	esac
	check_nostdout			# should be no stdout
	check_stderr			# should be stderr
	tpresult 			# set result code
}

startup() # startup function
{
     rm -f out.stdout out.stderr out.experr >/dev/null 2>&1
}


cleanup() # clean-up function
{
     rm -f out.stdout out.stderr out.experr >/dev/null 2>&1
}

# source common shell functions

. $TET_EXECUTE/LIB/shfuncs.sh
. $TET_EXECUTE/LIB/lsbfuncs.sh

# execute shell test case manager - must be last line
. $TET_ROOT/lib/xpg3sh/tcm.sh
